==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/WebPanePinnedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPanePinnedEventArgsDescription } from "./WebPanePinnedEventArgsDescription";
/**
 * @hidden
 */
export let WebPanePinnedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPanePinnedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPanePinnedEventArgsDescriptionMetadata.a == null) {
                WebPanePinnedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPanePinnedEventArgsDescriptionMetadata.c(WebPanePinnedEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebPanePinnedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebPanePinnedEventArgsDescriptionMetadata.a);
            WebContentPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PanePinnedEventArgs");
            a.item("SourcePane", "ExportedType:WebContentPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
            a.item("NewValue", "Boolean");
            a.item("Location", "ExportedType:string:PanePinnedEventArgsLocation");
            a.item("Location@names", "Top;Bottom;Left;Right");
        }
        static d(a) {
            WebPanePinnedEventArgsDescriptionMetadata.b(a);
            a.u("WebPanePinnedEventArgs", () => new WebPanePinnedEventArgsDescription());
            a.t("WebPanePinnedEventArgs", WebPanePinnedEventArgsDescriptionMetadata.a);
        }
    }
    WebPanePinnedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPanePinnedEventArgsDescriptionMetadata, 'WebPanePinnedEventArgsDescriptionMetadata');
    WebPanePinnedEventArgsDescriptionMetadata.a = null;
    return WebPanePinnedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebPanePinnedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPanePinnedEventArgsDescription } from "./WebPanePinnedEventArgsDescription";
/**
 * @hidden
 */
export let WebPanePinnedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPanePinnedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPanePinnedEventArgsDescriptionMetadata.a == null) {
                WebPanePinnedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPanePinnedEventArgsDescriptionMetadata.c(WebPanePinnedEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebPanePinnedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebPanePinnedEventArgsDescriptionMetadata.a);
            WebContentPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PanePinnedEventArgs");
            a.item("SourcePane", "ExportedType:WebContentPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
            a.item("NewValue", "Boolean");
            a.item("Location", "ExportedType:string:PanePinnedEventArgsLocation");
            a.item("Location@names", "Top;Bottom;Left;Right");
        }
        static d(a) {
            WebPanePinnedEventArgsDescriptionMetadata.b(a);
            a.aa("WebPanePinnedEventArgs", () => new WebPanePinnedEventArgsDescription());
            a.z("WebPanePinnedEventArgs", WebPanePinnedEventArgsDescriptionMetadata.a);
        }
    }
    WebPanePinnedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPanePinnedEventArgsDescriptionMetadata, 'WebPanePinnedEventArgsDescriptionMetadata');
    WebPanePinnedEventArgsDescriptionMetadata.a = null;
    return WebPanePinnedEventArgsDescriptionMetadata;
})();
